import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';
import 'package:zhiying_base_widget/dialog/select_date_ym_dialog/select_date_ym_dialog.dart';
import 'package:zhiying_base_widget/widgets/wallet/wallet_detail/wallet_detail_bloc.dart';
import 'package:zhiying_base_widget/widgets/wallet_bil_detail/wallet_bil_detail_widget_bloc.dart';
import 'package:zhiying_comm/util/base_bloc.dart';
import 'package:zhiying_comm/zhiying_comm.dart';

import 'model/wallet_style_model.dart';

class WalletListWidget extends StatefulWidget {
 final TabList tabList;
 final List<InputTabViewBtns> tabViewBtns;
  const WalletListWidget({Key key,this.tabViewBtns, this.tabList}) : super(key: key);
  @override
  _WalletListWidgetState createState() => _WalletListWidgetState();
}

class _WalletListWidgetState extends State<WalletListWidget> with AutomaticKeepAliveClientMixin {
  WalletBilDetailWidgetBloc _bloc;
  List<InputTabViewBtns> tabViewBtns;
  TabList item;

  @override
  void initState() {
    item=widget.tabList;
    tabViewBtns=widget.tabViewBtns;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    _bloc = BlocProvider.of(context);
    if(item.type=='input'){
      return StreamBuilder(
          stream: _bloc.inputOutData,
          builder: (context, asny) {
            // dataVM = asny.data;

            return Container(
              child: Column(
                children: <Widget>[
                  _buildType(tabViewBtns, item),
                  Expanded(
                    child: SmartRefresher(
                        controller: _bloc.inputRefreshController,
                        enablePullDown: true,
                        enablePullUp: true,
                        onLoading: _bloc.outputLoad(),
                        onRefresh: _bloc.outputRefresh(),
                        child: _bloc.inputDataVM == null
                            ? Container()
                            : _buildBottomItem(item)),
                  )
                ],
              ),
            );
          });
    }else{
      return StreamBuilder(
          stream: _bloc.outputOutData,
          builder: (context, asny) {
            // dataVM = asny.data;

            return Container(
              child: Column(
                children: <Widget>[
                  _buildType(tabViewBtns, item),
                  Expanded(
                    child: SmartRefresher(
                        controller: _bloc.outputRefreshController,
                        enablePullDown: true,
                        enablePullUp: true,
                        onLoading: _bloc.outputLoad(),
                        onRefresh: _bloc.outputRefresh(),
                        child: _bloc.outputDataVM == null
                            ? Container()
                            : _buildBottomItem(item)),
                  )
                ],
              ),
            );
          });
    }


  }



  _buildType(List<InputTabViewBtns> tabViewBtns, TabList tabList) {
    var selectType;
    if (tabList.type == 'input') {
      selectType = _bloc.inputSelectType;
    } else {
      selectType = _bloc.outputSelectType;
      ;
    }
    return Row(
      children: <Widget>[
        SizedBox(width: 12.5),
        InkWell(
          onTap: () {
            ///显示日期选择弹窗
            _selectDate(tabList);
          },
          child: Padding(
              padding: const EdgeInsets.only(top: 8, bottom: 8),
              child: Text(
                  tabList.type == "input"
                      ? _bloc.inputShowDate
                      : _bloc.outputShowDate,
                  style: TextStyle(
                      fontSize: 28.sp,
                      color:
                      HexColor.fromHex(_bloc.styleData.timeSelectColor)))),
        ),
        Icon(
          Icons.arrow_drop_down,
          color: HexColor.fromHex(_bloc.styleData.timeSelectColor),
        ),
        Expanded(
            child: Container(
              height: 50,
              child: ListView.builder(
                  scrollDirection: Axis.horizontal,
                  shrinkWrap: true,
                  itemCount: tabViewBtns.length,
                  itemBuilder: (context, index) {
                    return InkWell(
                        onTap: () async {
                          if (tabList.type == 'input') {
                            _bloc.inputSelectType = tabViewBtns[index].type;
                            _bloc.loadInputData(
                                _bloc.inPutCurrentPage, _bloc.inputShowDate,
                                type: _bloc.inputSelectType);
                          } else {
                            _bloc.outputSelectType = tabViewBtns[index].type;
                            _bloc.loadOutputData(
                                _bloc.outPutCurrentPage, _bloc.outputShowDate,
                                type: _bloc.outputSelectType);
                          }
                          _bloc.refresh();
                        },
                        child: Container(
                          margin: EdgeInsets.only(
                              top: 10, left: 8, right: 8, bottom: 10),
                          decoration: BoxDecoration(
                              border: Border.all(
                                color: HexColor.fromHex(
                                    selectType == tabViewBtns[index].type
                                        ? _bloc.styleData.btnSelectedColor
                                        : _bloc.styleData.btnNoSelectedColor),
                              ),
                              borderRadius: BorderRadius.circular(50)),
                          child: Padding(
                            padding: EdgeInsets.only(left: 16, right: 16),
                            child: Center(
                                child: Text(
                                  tabViewBtns[index].name ?? "",
                                  style: TextStyle(
                                      color: HexColor.fromHex(
                                          selectType == tabViewBtns[index].type
                                              ? _bloc.styleData.btnSelectedColor
                                              : _bloc.styleData.btnNoSelectedColor)),
                                )),
                          ),
                        ));
                  }),
            ))
      ],
    );
  }

  _selectDate(TabList tabList) async {
    var result = await showDialog(
        context: context, builder: (context) => SelectDateYMDialog());
    if (result != null) {
      var dataTime = DateFormat('yyyy-MM').format(
          DateTime(int.parse(result['year']), int.parse(result['month'])));
      if (tabList.type == "input") {
        _bloc.inputShowDate = dataTime;
        _bloc.loadInputData(_bloc.inPutCurrentPage, _bloc.inputShowDate);
      } else {
        _bloc.outputShowDate = dataTime;
        _bloc.loadInputData(_bloc.outPutCurrentPage, _bloc.outputShowDate);
      }
      _bloc.refresh();
    }
  }




  _buildBottomItem(TabList tabList) {
    return ListView.builder(
        shrinkWrap: true,
        itemCount: tabList.type == 'input'
            ? _bloc.inputDataVM?.length??0
            : _bloc.outputDataVM?.length??0,
        itemBuilder: (context, index) {
          return _buildItem(context, index, tabList);
        });
  }

  Widget _buildItem(BuildContext context, int index, TabList tabList) {
    if (tabList.type == 'input') {
      InputItemStyle inputItemStyle = _bloc.styleData.inputItemStyle;
      var modelItem = _bloc.inputDataVM[index];
      return Container(
        margin: EdgeInsets.only(left: 12.5, right: 12.5, bottom: 4, top: 4),
        padding:
        EdgeInsets.only(left: 25.w, right: 25.w, top: 20.h, bottom: 20.h),
        decoration: BoxDecoration(
            color: HexColor.fromHex("#FFFFFF"),
            borderRadius: BorderRadius.circular(8)),
        child: Column(
          children: <Widget>[
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: <Widget>[
                Row(
                  children: <Widget>[
                    Container(
                      decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(4),
                          color: HexColor.fromHex("#FFFFF3F3"),
                          border: Border.all(
                              color: HexColor.fromHex(
                                  inputItemStyle.typeNameColor))),
                      child: Padding(
                        padding: const EdgeInsets.only(
                            left: 4, right: 4, top: 2, bottom: 2),
                        child: Center(
                          child: Text(
                            modelItem['type'] ?? "",
                            style: TextStyle(
                                color: HexColor.fromHex(
                                    inputItemStyle.typeNameColor),
                                fontSize: 20.sp),
                          ),
                        ),
                      ),
                    ),
                    Container(
                        width: 353.w,
                        margin: EdgeInsets.only(left: 15.w),
                        child: Text(
                          modelItem['title'] ?? "",
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(fontSize: 28.sp),
                        ))
                  ],
                ),
                Row(
                  children: <Widget>[
                    Text(
                      "+ ",
                      style: TextStyle(
                          color: HexColor.fromHex(inputItemStyle.amountColor)),
                    ),
                    Text(
                      "¥ " + modelItem['amount'],
                      style: TextStyle(
                          color: HexColor.fromHex(inputItemStyle.amountColor),
                          fontSize: 30.sp),
                    )
                  ],
                )
              ],
            ),
            SizedBox(
              height: 4,
            ),

            ///订单编号
            Row(
              children: <Widget>[
                Text(
                  inputItemStyle.orderIdText,
                  style: TextStyle(
                      color: HexColor.fromHex(inputItemStyle.contentColor),
                      fontSize: 22.sp),
                ),
                SizedBox(
                  width: 4,
                ),
                Text(
                  modelItem['order_id'],
                  style: TextStyle(
                      color: HexColor.fromHex(inputItemStyle.contentColor),
                      fontSize: 22.sp),
                ),
                SizedBox(
                  width: 28.w,
                ),
                Container(
                  decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(4),
                      color: HexColor.fromHex(inputItemStyle.copyBtnBgColor),
                      border: Border.all(
                          color:
                          HexColor.fromHex(inputItemStyle.contentColor))),
                  child: Padding(
                    padding:
                    EdgeInsets.only(left: 16, right: 16, top: 1, bottom: 1),
                    child: Text(
                      inputItemStyle.copyBtnText,
                      style: TextStyle(
                          color: HexColor.fromHex(inputItemStyle.contentColor),
                          fontSize: 22.sp),
                    ),
                  ),
                )
              ],
            ),
            SizedBox(
              height: 4,
            ),
            Row(
              children: <Widget>[
                Expanded(
                    child: Row(
                      children: <Widget>[
                        Text(
                          inputItemStyle.orderTypeText,
                          style: TextStyle(
                              color: HexColor.fromHex(inputItemStyle.contentColor),
                              fontSize: 22.sp),
                        ),
                        SizedBox(
                          width: 4,
                        ),
                        Text(
                          modelItem['order_type'] ?? "",
                          style: TextStyle(
                              color: HexColor.fromHex("#FF999999"),
                              fontSize: 22.sp),
                        ),
                      ],
                    )),
                Expanded(
                    child: Row(
                      children: <Widget>[
                        Text(
                          inputItemStyle.amountText + " ¥" + modelItem['amount'],
                          style: TextStyle(
                              color: HexColor.fromHex(inputItemStyle.contentColor),
                              fontSize: 22.sp),
                        ),
                      ],
                    ))
              ],
            ),
            SizedBox(
              height: 4,
            ),
            Row(
              children: <Widget>[
                Expanded(
                    child: Row(
                      children: <Widget>[
                        Text(
                          inputItemStyle.timeText,
                          style: TextStyle(
                              color: HexColor.fromHex(inputItemStyle.contentColor),
                              fontSize: 22.sp),
                        ),
                        SizedBox(
                          width: 4,
                        ),
                        Text(
                          modelItem['time'] ?? "",
                          style: TextStyle(
                              color: HexColor.fromHex("#FF999999"),
                              fontSize: 22.sp),
                        ),
                      ],
                    )),
                Expanded(
                    child: Row(
                      children: <Widget>[
                        Text(
                          inputItemStyle.settleTimeText +
                              " " +
                              modelItem['settle_time'] ??
                              "",
                          style: TextStyle(
                              color: HexColor.fromHex(inputItemStyle.contentColor),
                              fontSize: 22.sp),
                        ),
                      ],
                    ))
              ],
            ),
          ],
        ),
      );
    } else if (tabList.type == 'output') {
      OutputItemStyle inputItemStyle = _bloc.styleData.outputItemStyle;
      var modelItem = _bloc.outputDataVM[index];
      if (modelItem['type'] == '消费') {
        ///消费返回的Item
        return Container(
          margin: EdgeInsets.only(left: 12.5, right: 12.5, bottom: 4, top: 4),
          padding:
          EdgeInsets.only(left: 25.w, right: 25.w, top: 20.h, bottom: 20.h),
          decoration: BoxDecoration(
              color: HexColor.fromHex("#FFFFFF"),
              borderRadius: BorderRadius.circular(8)),
          child: Column(
            children: <Widget>[
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Row(
                    children: <Widget>[
                      Container(
                        decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(4),
                            color: HexColor.fromHex("#FFFFF3F3"),
                            border: Border.all(
                                color: HexColor.fromHex(
                                    inputItemStyle.typeNameColor))),
                        child: Padding(
                          padding: const EdgeInsets.only(
                              left: 4, right: 4, top: 2, bottom: 2),
                          child: Center(
                            child: Text(
                              modelItem['type'] ?? "",
                              style: TextStyle(
                                  color: HexColor.fromHex(
                                      inputItemStyle.typeNameColor),
                                  fontSize: 20.sp),
                            ),
                          ),
                        ),
                      ),
                      Container(
                          width: 353.w,
                          margin: EdgeInsets.only(left: 15.w),
                          child: Text(
                            modelItem['title'] ?? "",
                            maxLines: 1,
                            overflow: TextOverflow.ellipsis,
                            style: TextStyle(fontSize: 28.sp),
                          ))
                    ],
                  ),
                  Row(
                    children: <Widget>[
                      Text(
                        "- ",
                        style: TextStyle(color: Colors.red),
                      ),
                      Text(
                        "¥ " + modelItem['amount'],
                        style: TextStyle(color: Colors.red, fontSize: 30.sp),
                      )
                    ],
                  )
                ],
              ),
              SizedBox(
                height: 4,
              ),

              ///订单编号
              Row(
                children: <Widget>[
                  Text(
                    inputItemStyle.orderIdText,
                    style: TextStyle(
                        color: HexColor.fromHex(inputItemStyle.contentColor),
                        fontSize: 22.sp),
                  ),
                  SizedBox(
                    width: 4,
                  ),
                  Text(
                    modelItem['order_id'],
                    style: TextStyle(
                        color: HexColor.fromHex(inputItemStyle.contentColor),
                        fontSize: 22.sp),
                  ),
                  SizedBox(
                    width: 28.w,
                  ),
                  Container(
                    decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(4),
                        color: HexColor.fromHex(inputItemStyle.copyBtnBgColor),
                        border: Border.all(
                            color:
                            HexColor.fromHex(inputItemStyle.contentColor))),
                    child: Padding(
                      padding: EdgeInsets.only(
                          left: 16, right: 16, top: 1, bottom: 1),
                      child: Text(
                        inputItemStyle.copyBtnText ?? "",
                        style: TextStyle(
                            color:
                            HexColor.fromHex(inputItemStyle.contentColor),
                            fontSize: 22.sp),
                      ),
                    ),
                  )
                ],
              ),
              SizedBox(
                height: 4,
              ),
              Row(
                children: <Widget>[
                  Expanded(
                      child: Row(
                        children: <Widget>[
                          Text(
                            inputItemStyle.consumeOrderTypeText,
                            style: TextStyle(
                                color:
                                HexColor.fromHex(inputItemStyle.contentColor),
                                fontSize: 22.sp),
                          ),
                          SizedBox(
                            width: 4,
                          ),
                          Text(
                            modelItem['order_type'] ?? "",
                            style: TextStyle(
                                color: HexColor.fromHex("#FF999999"),
                                fontSize: 22.sp),
                          ),
                        ],
                      )),
                  Expanded(
                      child: Row(
                        children: <Widget>[
                          Text(
                            inputItemStyle.consumeAmountText +
                                " ¥" +
                                modelItem['amount'],
                            style: TextStyle(
                                color:
                                HexColor.fromHex(inputItemStyle.contentColor),
                                fontSize: 22.sp),
                          ),
                        ],
                      ))
                ],
              ),
              SizedBox(
                height: 4,
              ),
              Row(
                children: <Widget>[
                  Expanded(
                      child: Row(
                        children: <Widget>[
                          Text(
                            inputItemStyle.consumeTimeText,
                            style: TextStyle(
                                color:
                                HexColor.fromHex(inputItemStyle.contentColor),
                                fontSize: 22.sp),
                          ),
                          SizedBox(
                            width: 4,
                          ),
                          Text(
                            modelItem['time'] ?? "",
                            style: TextStyle(
                                color: HexColor.fromHex("#FF999999"),
                                fontSize: 22.sp),
                          ),
                        ],
                      )),
                  // Expanded(
                  //     child: Row(
                  //       children: <Widget>[
                  //         Text(
                  //           inputItemStyle.consumeTimeText +
                  //               " " +
                  //               modelItem['settle_time'] ??
                  //               "",
                  //           style: TextStyle(
                  //               color: HexColor.fromHex(inputItemStyle.contentColor),
                  //               fontSize: 22.sp),
                  //         ),
                  //       ],
                  //     ))
                ],
              ),
            ],
          ),
        );
      } else {}
    }
  }

  @override
  // TODO: implement wantKeepAlive
  bool get wantKeepAlive => true;
}
